<?php

namespace PAR\Factory;

use Doctrine\ORM\EntityManager;
use PAR\Traits\TQuery;


class TrocaDeInscricaoParceiroFactory{

    use TQuery;

    protected $connection;
    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
    
    public function getContratosApenasDelphi(array $params) {
        $sql = "SELECT NRSEQCONTRATO
                  FROM CONTRATOLINP
                 WHERE NRSEQCONTRATO IS NULL
                   AND DTCONTLINPRESC IS NULL
                   AND NRORG     = :NRORG
                   AND CDCLIENTE = (SELECT CDCLIENTE 
                                      FROM CLIENTE 
                                     WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO)";
        
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    /*  $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); */
    }

    public function getInscricaoParceiro($param) {

      $sql = "SELECT DISTINCT PARCNEGOCIO.*,
                DECODE(PARCNEGOCIO.IDATIVO,'S','Sim','Não') AS NMATIVO,
                OPERADOR.NMOPERADOR AS NMOPERRESPONSAVEL,
                OPERTROCA.NMOPERADOR AS NMOPERALTCNPJPARC,
                LOGPARC.NROLDINSCRICAO,
                LOGPARC.NRNEWINSCRICAO,
                TO_CHAR(LOGPARC.DTALTCNPJPARCEIRO, 'DD/MM/YYYY HH24:MI') AS DTALTCNPJPARCEIRO,
                LOGPARC.NMARQUIVO,
                LOGPARC.DSCAMINHOARQ,
                LOGPARC.DSTIPO,
                LOGPARC.VRTAMANHO,
                LOGPARC.CDOPERINCLUSAO AS CDOPERALTCNPJPARC,
                LOGPARC.DSJUSTIFICATIVA
            FROM PARCNEGOCIO
                LEFT JOIN PARCERIA ON PARCNEGOCIO.NRPARCNEGOCIO = PARCERIA.NRPARCNEGOCIO
                AND PARCNEGOCIO.NRORG = PARCERIA.NRORG
                LEFT JOIN OPERADOR ON PARCNEGOCIO.CDOPERRESPONSAVEL = OPERADOR.CDOPERADOR
                AND PARCNEGOCIO.NRORG = OPERADOR.NRORG
                LEFT JOIN
              (SELECT *
               FROM CRM_HIERARQUIAOPER
               WHERE CDOPERADOR = :P_CDOPERADOR) OPERHIERAR ON OPERHIERAR.NRORG = PARCNEGOCIO.NRORG
            LEFT JOIN FCT_PARAMETROGERAL PARAM ON PARCNEGOCIO.NRORG = PARAM.NRORG
            LEFT JOIN FCT_LOGALTCNPJPARCEIRO LOGPARC ON PARCNEGOCIO.NRINSCRICAOPARC = LOGPARC.NRNEWINSCRICAO
            AND PARCNEGOCIO.NRORG = LOGPARC.NRORG
            LEFT JOIN OPERADOR OPERTROCA ON LOGPARC.CDOPERINCLUSAO = OPERTROCA.CDOPERADOR
            AND LOGPARC.NRORG = OPERTROCA.NRORG
            WHERE (PARCERIA.CDTIPOPARCEIRO IN('CLIENTE')
                   AND PARCERIA.IDATIVO = 'S'
                   AND PARCNEGOCIO.IDATIVO = 'S')
              AND ((PARAM.IDUTILIZAHIEROPER = 'S'
                    AND (PARCNEGOCIO.CDOPERRESPONSAVEL IN
                           (SELECT CDOPERADOR
                            FROM CRM_HIERARQUIAOPER
                            WHERE (CRM_HIERARQUIAOPER.CDFILIAL = OPERHIERAR.CDFILIAL
                                   OR CRM_HIERARQUIAOPER.CDFILIAL IS NULL) CONNECT BY
                              PRIOR CRM_HIERARQUIAOPER.NRHIERARQUIAOPER = CRM_HIERARQUIAOPER.NRHIERARQUIAPAI
                              START WITH CRM_HIERARQUIAOPER.CDOPERADOR = OPERHIERAR.CDOPERADOR))
                    OR PARCNEGOCIO.CDOPERRESPONSAVEL IS NULL)
                   OR (OPERHIERAR.IDOPERMASTER = 'S')
                   OR (PARAM.IDUTILIZAHIEROPER = 'N'))";

      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $param);
    }

    public function validaOrganizacao(array $params) {
        $sql = "SELECT COUNT(*) AS VALIDA
                  FROM ORGANIZACAO
                 WHERE NRINSJUREMPR = :NRINSJUREMPR
                   AND IDATIVO = 'S'";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $aux = $std->fetchAll();
        return $aux[0]["VALIDA"];
    }

    public function validaParceiro(array $params) {
        $sql = "SELECT COUNT(*) AS VALIDA
                  FROM PARCNEGOCIO
                 WHERE NRINSCRICAOPARC = :NRINSCRICAOPARC
                   AND NRORG = :NRORG
                   AND IDATIVO = 'S'";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $aux = $std->fetchAll();
        return $aux[0]["VALIDA"];
    }
    
    public function inserirLogAltCnpjParceiro(array $params) {
        $sql = "INSERT INTO FCT_LOGALTCNPJPARCEIRO (
                    NRALTCNPJPARCEIRO, NROLDINSCRICAO, NRNEWINSCRICAO,
                    DTALTCNPJPARCEIRO, NMARQUIVO,      DSCAMINHOARQ,
                    DSTIPO,            VRTAMANHO,      IDATIVO,
                    DTINCLUSAO,        NRORGINCLUSAO,  NRORG,
                    CDOPERINCLUSAO,    DSJUSTIFICATIVA
                ) VALUES (
                    :NRALTCNPJPARCEIRO, :NROLDINSCRICAO, :NRNEWINSCRICAO,
                    SYSDATE,            :NMARQUIVO,      :DSCAMINHOARQ,
                    :DSTIPO,            :VRTAMANHO,      'S',
                    SYSDATE,            :NRORG,          :NRORG,
                    :CDOPERINCLUSAO,    :DSJUSTIFICATIVA
                )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function getTermoAnuenciaParceiro(array $params) {
        $sql = "SELECT NMARQUIVO,
                       DSCAMINHOARQ,
                       DSTIPO,
                       VRTAMANHO
                  FROM FCT_LOGALTCNPJPARCEIRO
                 WHERE NRNEWINSCRICAO = :NRINSCRICAOPARC
                   AND NRORG          = :NRORG";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }
}